@@ -1,14 +1,22 @@
+use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151450';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151480';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
 use MojoX::AlmostJSON qw(encode_json);
 use constant DEBUG => 0;
 
+#Not sure why C<out> function have to decode from utf8,
+#but it make my day!
+our $OUT_DECODE = 'UTF-8';
+
+
 sub out{
 	my $tag = shift;
-	return Mojo::ByteStream->new($tag);
+	my $bytes = Mojo::ByteStream->new($tag);
+	return $bytes->decode($OUT_DECODE) if defined $OUT_DECODE;
+	return $bytes;
 }
 
 sub new{
@@ -131,6 +139,30 @@ sub dxpopup{
 	dxbind( $c, 'dxPopup' => $id => $attrs );
 }
 
+
+sub dxswitch{
+	my $c = shift;
+	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
+	my $id = delete($attrs->{id});
+	if (my $name = $id) {
+		$attrs->{attr}{name}=$name;
+	}
+	$id //= new_id( $c, $attrs );
+	$attrs->{onText}  //= 'On';
+	$attrs->{offText} //= 'Off';
+	my (@before, @after);
+	if(my $label = delete($attrs->{label})){
+		push @before, '<div class="dx-field">';
+		push @before, '<div class="dx-field-label">'.$label.'</div>';
+		push @before, '<div class="dx-field-value">';
+		push @after, '</div>';
+		push @after, '</div>';
+	}
+	
+	dxbind( $c, 'dxSwitch' => $id => $attrs, undef, \@before, \@after );	
+}
+
+
 sub dxtextbox{
 	my $c = shift;
 	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
@@ -239,7 +271,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.151450
+version 0.151480
 
 =head1 SUBROUTINES/METHODS
 
@@ -322,6 +354,10 @@ B<Note: It will ignore all other options specified in the hash reference.>
 			contentElement.append('<p>Hello!</p>');
 		}};
 
+=head2 dxswitch C<[ $id [, $value [, $label] ] ], [\%opts]>
+
+	%= dxswitch 'mySwitch' => $boolean_value => 'Enabled: '
+
 =head2 dxtextbox C<[ $id, [ $value, [ $label, ] ] ], [\%opts]>
 
 	%= dxtextbox 'name' => $value => 'Name: ', { placeHolder => 'Type a name' }
